@@ -1,16 +1,20 @@
-# Copyrights 2001-2017 by [Mark Overmeer].
+# Copyrights 2001-2018 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-use strict;
-use warnings;
+# This code is part of distribution Mail-Message.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Mail::Message::Field;
 use vars '$VERSION';
-$VERSION = '3.003';
+$VERSION = '3.007';
 
 use base 'Mail::Reporter';
 
+use strict;
+use warnings;
+
 use Carp;
 use Mail::Address;
 use Date::Format 'strftime';
@@ -135,8 +139,9 @@ sub body()
     my $body = $self->unfoldedBody;
     return $body unless $self->isStructured;
 
-    $body =~ s/\s*\;.*//s;
-    $body;
+    my ($first) = $body =~ m/^((?:"[^"]*"|'[^']*'|[^;])*)/;
+	$first =~ s/\s+$//;
+	$first;
 }
 
 
@@ -462,8 +467,9 @@ sub fold($$;$)
 sub unfold($)
 {   my $string = $_[1];
     for($string)
-    {   s/\r?\n//gm;
+    {   s/\r?\n\s?/ /gs;  # remove FWS
         s/^ +//;
+        s/ +$//;
     }
     $string;
 }
